ml_text_summarizer library

๐ŸŒ ml_text_summarizer

A lightweight, multilingual extractive text summarization library written in pure Dart. Supports Turkish ๐Ÿ‡น๐Ÿ‡ท and English ๐Ÿ‡บ๐Ÿ‡ธ out of the box, with the ability to extend to any language.

Created by Mehmet ร‡elik โ€” MIT License

Classes

TextSummarizer
TextSummarizer is a simple frequency-based extractive summarizer. It selects the most important sentences from the input text based on word frequency.