ml_text_summarizer library
๐ ml_text_summarizer
A lightweight, multilingual extractive text summarization library written in pure Dart. Supports Turkish ๐น๐ท and English ๐บ๐ธ out of the box, with the ability to extend to any language.
Created by Mehmet รelik โ MIT License
Classes
- TextSummarizer
- TextSummarizer is a simple frequency-based extractive summarizer. It selects the most important sentences from the input text based on word frequency.